/**
 * Copyright 2021-2022, Optimizely
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { setLogHandler, setLogLevel } from '@optimizely/js-sdk-logging';
import defaultErrorHandler from './plugins/error_handler';
import noOpEventDispatcher from './plugins/event_dispatcher/no_op';
import * as enums from './utils/enums';
import * as loggerPlugin from './plugins/logger';
import { OptimizelyDecideOption, Client, ConfigLite } from './shared_types';
/**
 * Creates an instance of the Optimizely class
 * @param  {ConfigLite} config
 * @return {Client|null} the Optimizely client object
 *                           null on error
 */
declare const createInstance: (config: ConfigLite) => Client | null;
export { loggerPlugin as logging, defaultErrorHandler as errorHandler, noOpEventDispatcher as eventDispatcher, enums, setLogHandler as setLogger, setLogLevel, createInstance, OptimizelyDecideOption, };
declare const _default: {
    logging: typeof loggerPlugin;
    errorHandler: {
        handleError: typeof import("./plugins/error_handler").handleError;
    };
    eventDispatcher: {
        dispatchEvent: (eventObj: import("./shared_types").Event, callback: (response: {
            statusCode: number;
        }) => void) => void;
    };
    enums: typeof enums;
    setLogger: typeof setLogHandler;
    setLogLevel: typeof setLogLevel;
    createInstance: (config: ConfigLite) => Client | null;
    OptimizelyDecideOption: typeof OptimizelyDecideOption;
};
export default _default;
export * from './export_types';
