/****************************************************************************
 * Copyright 2016-2022, Optimizely, Inc. and contributors                   *
 *                                                                          *
 * Licensed under the Apache License, Version 2.0 (the "License");          *
 * you may not use this file except in compliance with the License.         *
 * You may obtain a copy of the License at                                  *
 *                                                                          *
 *    http://www.apache.org/licenses/LICENSE-2.0                            *
 *                                                                          *
 * Unless required by applicable law or agreed to in writing, software      *
 * distributed under the License is distributed on an "AS IS" BASIS,        *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 * See the License for the specific language governing permissions and      *
 * limitations under the License.                                           *
 ***************************************************************************/
/**
 * Contains global enums used throughout the library
 */
export declare const LOG_LEVEL: {
    NOTSET: number;
    DEBUG: number;
    INFO: number;
    WARNING: number;
    ERROR: number;
};
export declare const ERROR_MESSAGES: {
    CONDITION_EVALUATOR_ERROR: string;
    DATAFILE_AND_SDK_KEY_MISSING: string;
    EXPERIMENT_KEY_NOT_IN_DATAFILE: string;
    FEATURE_NOT_IN_DATAFILE: string;
    IMPROPERLY_FORMATTED_EXPERIMENT: string;
    INVALID_ATTRIBUTES: string;
    INVALID_BUCKETING_ID: string;
    INVALID_DATAFILE: string;
    INVALID_DATAFILE_MALFORMED: string;
    INVALID_CONFIG: string;
    INVALID_JSON: string;
    INVALID_ERROR_HANDLER: string;
    INVALID_EVENT_DISPATCHER: string;
    INVALID_EVENT_TAGS: string;
    INVALID_EXPERIMENT_KEY: string;
    INVALID_EXPERIMENT_ID: string;
    INVALID_GROUP_ID: string;
    INVALID_LOGGER: string;
    INVALID_ROLLOUT_ID: string;
    INVALID_USER_ID: string;
    INVALID_USER_PROFILE_SERVICE: string;
    NO_DATAFILE_SPECIFIED: string;
    NO_JSON_PROVIDED: string;
    NO_VARIATION_FOR_EXPERIMENT_KEY: string;
    UNDEFINED_ATTRIBUTE: string;
    UNRECOGNIZED_ATTRIBUTE: string;
    UNABLE_TO_CAST_VALUE: string;
    USER_NOT_IN_FORCED_VARIATION: string;
    USER_PROFILE_LOOKUP_ERROR: string;
    USER_PROFILE_SAVE_ERROR: string;
    VARIABLE_KEY_NOT_IN_DATAFILE: string;
    VARIATION_ID_NOT_IN_DATAFILE: string;
    VARIATION_ID_NOT_IN_DATAFILE_NO_EXPERIMENT: string;
    INVALID_INPUT_FORMAT: string;
    INVALID_DATAFILE_VERSION: string;
    INVALID_VARIATION_KEY: string;
};
export declare const LOG_MESSAGES: {
    ACTIVATE_USER: string;
    DISPATCH_CONVERSION_EVENT: string;
    DISPATCH_IMPRESSION_EVENT: string;
    DEPRECATED_EVENT_VALUE: string;
    EVENT_KEY_NOT_FOUND: string;
    EXPERIMENT_NOT_RUNNING: string;
    FEATURE_ENABLED_FOR_USER: string;
    FEATURE_NOT_ENABLED_FOR_USER: string;
    FEATURE_HAS_NO_EXPERIMENTS: string;
    FAILED_TO_PARSE_VALUE: string;
    FAILED_TO_PARSE_REVENUE: string;
    FORCED_BUCKETING_FAILED: string;
    INVALID_OBJECT: string;
    INVALID_CLIENT_ENGINE: string;
    INVALID_DEFAULT_DECIDE_OPTIONS: string;
    INVALID_DECIDE_OPTIONS: string;
    INVALID_VARIATION_ID: string;
    NOTIFICATION_LISTENER_EXCEPTION: string;
    NO_ROLLOUT_EXISTS: string;
    NOT_ACTIVATING_USER: string;
    NOT_TRACKING_USER: string;
    PARSED_REVENUE_VALUE: string;
    PARSED_NUMERIC_VALUE: string;
    RETURNING_STORED_VARIATION: string;
    ROLLOUT_HAS_NO_EXPERIMENTS: string;
    SAVED_VARIATION: string;
    SAVED_VARIATION_NOT_FOUND: string;
    SHOULD_NOT_DISPATCH_ACTIVATE: string;
    SKIPPING_JSON_VALIDATION: string;
    TRACK_EVENT: string;
    UNRECOGNIZED_DECIDE_OPTION: string;
    USER_ASSIGNED_TO_EXPERIMENT_BUCKET: string;
    USER_BUCKETED_INTO_EXPERIMENT_IN_GROUP: string;
    USER_BUCKETED_INTO_TARGETING_RULE: string;
    USER_IN_FEATURE_EXPERIMENT: string;
    USER_IN_ROLLOUT: string;
    USER_NOT_BUCKETED_INTO_EVERYONE_TARGETING_RULE: string;
    USER_NOT_BUCKETED_INTO_EXPERIMENT_IN_GROUP: string;
    USER_NOT_BUCKETED_INTO_ANY_EXPERIMENT_IN_GROUP: string;
    USER_NOT_BUCKETED_INTO_TARGETING_RULE: string;
    USER_NOT_IN_FEATURE_EXPERIMENT: string;
    USER_NOT_IN_ROLLOUT: string;
    USER_FORCED_IN_VARIATION: string;
    USER_MAPPED_TO_FORCED_VARIATION: string;
    USER_DOESNT_MEET_CONDITIONS_FOR_TARGETING_RULE: string;
    USER_MEETS_CONDITIONS_FOR_TARGETING_RULE: string;
    USER_HAS_VARIATION: string;
    USER_HAS_FORCED_DECISION_WITH_RULE_SPECIFIED: string;
    USER_HAS_FORCED_DECISION_WITH_NO_RULE_SPECIFIED: string;
    USER_HAS_FORCED_DECISION_WITH_RULE_SPECIFIED_BUT_INVALID: string;
    USER_HAS_FORCED_DECISION_WITH_NO_RULE_SPECIFIED_BUT_INVALID: string;
    USER_HAS_FORCED_VARIATION: string;
    USER_HAS_NO_VARIATION: string;
    USER_HAS_NO_FORCED_VARIATION: string;
    USER_HAS_NO_FORCED_VARIATION_FOR_EXPERIMENT: string;
    USER_NOT_IN_ANY_EXPERIMENT: string;
    USER_NOT_IN_EXPERIMENT: string;
    USER_RECEIVED_DEFAULT_VARIABLE_VALUE: string;
    FEATURE_NOT_ENABLED_RETURN_DEFAULT_VARIABLE_VALUE: string;
    VARIABLE_NOT_USED_RETURN_DEFAULT_VARIABLE_VALUE: string;
    USER_RECEIVED_VARIABLE_VALUE: string;
    VALID_DATAFILE: string;
    VALID_USER_PROFILE_SERVICE: string;
    VARIATION_REMOVED_FOR_USER: string;
    VARIABLE_REQUESTED_WITH_WRONG_TYPE: string;
    VALID_BUCKETING_ID: string;
    BUCKETING_ID_NOT_STRING: string;
    EVALUATING_AUDIENCE: string;
    EVALUATING_AUDIENCES_COMBINED: string;
    AUDIENCE_EVALUATION_RESULT: string;
    AUDIENCE_EVALUATION_RESULT_COMBINED: string;
    MISSING_ATTRIBUTE_VALUE: string;
    UNEXPECTED_CONDITION_VALUE: string;
    UNEXPECTED_TYPE: string;
    UNEXPECTED_TYPE_NULL: string;
    UNKNOWN_CONDITION_TYPE: string;
    UNKNOWN_MATCH_TYPE: string;
    UPDATED_OPTIMIZELY_CONFIG: string;
    OUT_OF_BOUNDS: string;
    UNABLE_TO_ATTACH_UNLOAD: string;
};
export declare const enum RESERVED_EVENT_KEYWORDS {
    REVENUE = "revenue",
    VALUE = "value"
}
export declare const CONTROL_ATTRIBUTES: {
    BOT_FILTERING: string;
    BUCKETING_ID: string;
    STICKY_BUCKETING_KEY: string;
    USER_AGENT: string;
    FORCED_DECISION_NULL_RULE_KEY: string;
};
export declare const JAVASCRIPT_CLIENT_ENGINE = "javascript-sdk";
export declare const NODE_CLIENT_ENGINE = "node-sdk";
export declare const REACT_CLIENT_ENGINE = "react-sdk";
export declare const REACT_NATIVE_CLIENT_ENGINE = "react-native-sdk";
export declare const REACT_NATIVE_JS_CLIENT_ENGINE = "react-native-js-sdk";
export declare const BROWSER_CLIENT_VERSION = "4.10.0";
export declare const NODE_CLIENT_VERSION = "4.10.0";
export declare const DECISION_NOTIFICATION_TYPES: {
    AB_TEST: string;
    FEATURE: string;
    FEATURE_TEST: string;
    FEATURE_VARIABLE: string;
    ALL_FEATURE_VARIABLES: string;
    FLAG: string;
};
export declare const DECISION_SOURCES: {
    FEATURE_TEST: string;
    ROLLOUT: string;
    EXPERIMENT: string;
};
export declare const AUDIENCE_EVALUATION_TYPES: {
    RULE: string;
    EXPERIMENT: string;
};
export declare const FEATURE_VARIABLE_TYPES: {
    BOOLEAN: string;
    DOUBLE: string;
    INTEGER: string;
    STRING: string;
    JSON: string;
};
export declare const DATAFILE_VERSIONS: {
    V2: string;
    V3: string;
    V4: string;
};
export declare const enum VERSION_TYPE {
    PRE_RELEASE_VERSION_DELIMITER = "-",
    BUILD_VERSION_DELIMITER = "+"
}
export declare const DECISION_MESSAGES: {
    SDK_NOT_READY: string;
    FLAG_KEY_INVALID: string;
    VARIABLE_VALUE_INVALID: string;
};
export declare enum NOTIFICATION_TYPES {
    ACTIVATE = "ACTIVATE:experiment, user_id,attributes, variation, event",
    DECISION = "DECISION:type, userId, attributes, decisionInfo",
    LOG_EVENT = "LOG_EVENT:logEvent",
    OPTIMIZELY_CONFIG_UPDATE = "OPTIMIZELY_CONFIG_UPDATE",
    TRACK = "TRACK:event_key, user_id, attributes, event_tags, event"
}
